<?php
/**
 * @file
 * Functions that support node type edit forms.
 */


/**
 * Implements hool_alter_node_form().
 *
 * Add reminder information when a node with reminders is displayed.
 *
 * @param array &$form
 *   The form to be altered.
 * @param array $form_state
 *   Current form state.
 * @param string $form_id
 *   Form id, in case there are more than one.
 *
 * No return value. The form is updated.
 */
function datereminder_alter_node_form(&$form, &$form_state, $form_id) {
  module_load_include('inc', 'datereminder', 'includes/defines');
  // Get type of node that we're editing.
  $type = $form['type']['#value'];
  $enabled = _datereminder_type_enabled($type);
  switch ($enabled) {
    case DATEREMINDER_TYPE_ON:
      $dflt = DATEREMINDER_TYPE_ON;
      break;

    case DATEREMINDER_TYPE_ALLOWED:
      $dflt = DATEREMINDER_TYPE_RETAIN;
      break;

    default:
      return;
  }

  // Node is not saved but previewed (nid is empty).
  if (isset($form['#node']->build_mode)
          && $form['#node']->build_mode == NODE_BUILD_PREVIEW) {
    $node = $form['#node'];
  }
  // Load the node if it already exists.
  elseif (!empty($form['nid']['#value'])) {
    $node = node_load($form['nid']['#value']);
  }
  else {
    $node = NULL;
  }
  if ($node != NULL && isset($node->datereminder_enabled)) {
    $dflt = $node->datereminder_enabled;
  }

  $form['reminder'] = array(
    '#type' => 'fieldset',
    '#title' => t('Reminder settings'),
    '#collapsible' => TRUE,
    '#collapsed' => TRUE,
    '#weight' => 40,
  );

  $radios[DATEREMINDER_TYPE_DISABLED] = t('Disable and discard existing reminders');
  $radios[DATEREMINDER_TYPE_RETAIN] = t('Disable, but keep existing reminders');
  $radios[DATEREMINDER_TYPE_ON] = t('Enable');

  $form['reminder']['datereminder_enabled'] = array(
    '#type' => 'radios',
    '#options' => $radios,
    '#default_value' => $dflt,
    '#description' => t('If enabled, users can sign up to get reminders before this event'),
  );

  $form['#submit'][] = '_datereminder_form_submit_node';
  $form['#validate'][] = '_datereminder_form_validate_node';
}

/**
 * Implements hook_node_type().
 *
 * @param array $form
 *   The current form
 * @param array $form_state
 *   ...and state
 * @param string $nodetype
 *   Type of node
 */
function datereminder_alter_node_type_form(&$form, &$form_state, $nodetype) {
  module_load_include('inc', 'datereminder', 'includes/defines');
  module_load_include('inc', 'datereminder', 'includes/date');

  $thisype = content_types($nodetype);

  $datetypes = _datereminder_supported_date_field_types();
  $fields = $thisype['fields'];
  if (!empty($fields) & is_array($fields)) {
    foreach ($thisype['fields'] as $afield) {
      if (array_key_exists($afield['type'], $datetypes)) {
        $datefields[$afield['field_name']] = $afield['widget']['label'];
        $lastkey = $afield['field_name'];
      }
    }
  }

  if (count($datefields) == 0) {
    $form['datereminder_enabled'] = array(
      '#type' => 'hidden',
      '#value' => DATEREMINDER_TYPE_DISABLED,
    );
  }
  else {
    // What is current setting?
    $enabled = _datereminder_type_enabled($nodetype);
    $currentfield = variable_get("datereminder_datefield_$nodetype", $lastkey);
    $form['reminder'] = array(
      '#type' => 'fieldset',
      '#title' => t('Reminder settings'),
      '#collapsible' => TRUE,
      '#collapsed' => TRUE,
      '#weight' => 20,
    );
    $radios[DATEREMINDER_TYPE_DISABLED] = t('Disabled');
    $radios[DATEREMINDER_TYPE_RETAIN]
      = t('Disabled, but retain any existing reminders');
    $radios[DATEREMINDER_TYPE_ALLOWED] = t('Allowed, off unless explicitly enabled');
    $radios[DATEREMINDER_TYPE_ON] = t('Allowed, automatically enabled for new nodes');
    $form['reminder']['datereminder_enabled'] = array(
      '#type' => 'radios',
      '#options' => $radios,
      '#default_value' => $enabled,
    );
    $form['reminder']['datereminder_all_on'] = array(
      '#type' => 'checkbox',
      '#title' => t('Enable reminders for existing nodes'),
      '#description' => t('Check if you want to enable reminders for existing nodes.'),
      '#default_value' => FALSE,
    );

    if (count($datefields) > 1) {
      $form['reminder']['datereminder_datefield'] = array(
        '#type' => 'select',
        '#options' => $datefields,
        '#default_value' => $currentfield,
        '#description' => t('Select which of several date fields to use for reminders'),
      );
      $lbl = t('Enable allowing users to request reminders for an event');
    }
    else {
      $form['reminder']['datereminder_datefield'] = array(
        '#type' => 'hidden',
        '#value' => $currentfield,
      );
      $lbl
        = t('Enable allowing users to request reminders for an event, based on field %date',
              array('%date' => $datefields[$lastkey]));
    }
    $form['reminder']['datereminder_enabled']['#description'] = $lbl;
    $form['#validate'][] = '_datereminder_form_validate_node_type';
    $form['#submit'][] = '_datereminder_form_submit_node_type';
  }
}
